@@ -3,7 +3,7 @@ __all__ = ('BankCardPoint',)
 from expressmoney.api import *
 
 
-SERVICE_NAME = 'payments'
+SERVICE = 'payments'
 
 
 class BankCardCreateContract(Contract):
@@ -83,17 +83,13 @@ class BankCardReadContract(BankCardCreateContract):
     gateway = serializers.ChoiceField(choices=GATEWAY_CHOICES)
 
 
-payments_bank_cards_bank_card = ID(SERVICE_NAME, 'bank_cards', 'bank_card')
+class BankCardID(ID):
+    _service = SERVICE
+    _app = 'bank_cards'
+    _view_set = 'bank_card'
 
 
 class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = payments_bank_cards_bank_card
+    _point_id = BankCardID()
     _create_contract = BankCardCreateContract
     _read_contract = BankCardReadContract
-
-
-"""
-from django.contrib.auth import get_user_model
-User = get_user_model()
-user = User.objects.get(id=1)
-"""
