@@ -49,11 +49,11 @@ class RequestError(PointError):
     def get_full_details(self):
         if not status.is_client_error(self.__status_code):
             raise PointError('Full details only for client errors')
-        self.__detail.update({
+        return {
+            'detail': self.__detail,
             'url': self.__url,
             'status_code': self.__status_code
-        })
-        return self.__status_code
+        }
 
 
 class ServerError(RequestError):
